# indent-concluder
A python library that uses indentation to generate neat summary reports.

## usage & example
[code](test.py)  
[tasks](doc/example/task.json)  
[conclusion](doc/example/conclusion.txt)

## license
[AGPL3.0](https://www.gnu.org/licenses/agpl.txt)